@@ -1,11 +1,11 @@
-from typing import Optional, List, Type, Callable, Any
+from typing import TYPE_CHECKING, Any, Callable, List, Optional, Type
 
 from .exceptions import Retry
 
-if False:
+if TYPE_CHECKING:
     from .models import TaskWrapper
 
-__all__ = ("task", "Retry")
+__all__ = ("task", "Retry", "clear_transaction_context")
 
 
 def task(
@@ -16,4 +16,10 @@ def task(
     return models_task(bind=bind, tags=tags, retries=retries)
 
 
+def clear_transaction_context() -> None:
+    from .models import TRANSACTION_CONTEXT
+
+    TRANSACTION_CONTEXT.clear()
+
+
 default_app_config = "robust.apps.RobustConfig"
